﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;

namespace UPlateCopy
{
    /// <summary>
    /// U盘文件操作类
    /// </summary>
    public static class zgFile
    {
        /// <summary>
        /// 复制文件
        /// </summary>
        /// <param name="fromDir">源文件夹路径</param>
        /// <param name="toDir">目标文件夹路径</param>
        public static void CopyDir(string fromDir, string toDir)
        {
            try//对文件操作权限不足进行放弃复制
            {
                if (!Directory.Exists(fromDir)) return;//判断源路径上是否存在文件夹

                if (!Directory.Exists(toDir))//判断目标路径上是否存在文件夹
                    Directory.CreateDirectory(toDir);//如果没有创建文件夹

                string[] files = Directory.GetFiles(fromDir);//获取路径下所有文件
                foreach (string formFileName in files)//循环下面的所有文件
                {
                    string fileName = Path.GetFileName(formFileName);//源文件名称(不含路径)
                    string toFileName = Path.Combine(toDir, fileName);//目标文件名称(含路径)

                    #region 在这里过滤要复制的文件格式

                    if (!File.Exists("Format.ini")) File.AppendAllText("Format.ini", "");//判断文件是否存在如果不存在新建个{复制格式配置文件}
                    List<string> CopyType = new List<string>((File.ReadAllText("Format.ini")).Replace("\r", "").Split('\n'));//获取要复制文件的格式
                    if (CopyType[0] != "") if (!CopyType.Exists(p => p.Equals(Path.GetExtension(fileName).ToLower()))) continue;//如果不是要复制的文件格式则跳过

                    #endregion 在这里过滤要复制的文件格式

                    #region 在这里判断要复制的文件是否存在

                    if (File.Exists(toFileName))//如果文件存在的话
                    {
                        if (new FileInfo(toFileName).Length != new FileInfo(formFileName).Length)//如果大小不一样
                        {
                            File.Delete(toFileName);//删除目标文件
                            File.Copy(formFileName, toFileName);//执行复制文件功能
                        }
                    }
                    else//如果文件不存在的话
                        File.Copy(formFileName, toFileName);//执行复制文件功能

                    #endregion 在这里判断要复制的文件是否存在
                }

                string[] fromDirs = Directory.GetDirectories(fromDir);//获取路径下所有文件夹
                foreach (string fromDirName in fromDirs)//循环下面的所有文件夹
                {
                    string dirName = Path.GetFileName(fromDirName);//源文件夹名称(不含路径)
                    string toDirName = Path.Combine(toDir, dirName);//目标文件夹名称(含路径)
                    CopyDir(fromDirName, toDirName);//递归   反复调用方法
                }
            }
            catch { }
        }

        /// <summary>
        /// 清理空文件夹
        /// </summary>
        /// <param name="fromDir">源文件夹路径</param>
        public static void DeleteNull(string fromDir)
        {
            string[] fromDirs = Directory.GetDirectories(fromDir);//获取路径下所有文件夹
            if (fromDirs.Count() == 0)//如果下面没有文件夹
            {
                string[] files = Directory.GetFiles(fromDir);//获取路径下所有文件
                if (files.Count() == 0) Directory.Delete(fromDir);//如果下面没有文件则删除文件夹
            }
            else//如果下面有文件夹
            {
                foreach (string fromDirName in fromDirs)//循环下面的所有文件夹
                {
                    DeleteNull(fromDirName);//递归 反复调用方法
                }
            }
        }

        /// <summary>
        /// 直接复制已经插入U盘的文件
        /// </summary>
        public static void zgUPlateAll()
        {
            DriveInfo[] drives = DriveInfo.GetDrives();
            foreach (DriveInfo DI in drives)
            {
                if (DI.DriveType == DriveType.Removable)
                {
                    CopyDir(DI.Name, File.ReadAllText("File.ini") + @"\" + DateTime.Now.ToString("yyyyMMddHHmmss"));
                }
            }
        }

        /// <summary>
        /// 生成并获取U盘ID
        /// </summary>
        /// <param name="symbol">盘符</param>
        /// <returns></returns>
        public static string zgUPlateId(string symbol)
        {
            string folder = DateTime.Now.ToString("yyyyMMddHHmmss");//用时间达到随机名称功能

            if (!File.Exists(symbol + @"Configuration.ini"))//判断目标路径上是否存在文件
                File.AppendAllText(symbol + @"Configuration.ini", zgMD5.GetMd5(folder));//如果没有创建文件

            return File.ReadAllText(symbol + @"Configuration.ini");
        }
    }
}